@@ -864,12 +864,12 @@ sub check_prereq {
     my $result = $self->SUPER::check_prereq(@_);
     unless ($result) {
 	$self->log_warn(<<END);
-  * Do not worry if some optional preqrequisites are missing. You can install *
-  * them later if you need the features they provide. Do not proceed with the *
-  * install if any of REQUIRED prerequisites are missing.                     *
-  *                                                                           *
-  * The optional Safe::World module does not currently run on Perl 5.10 or    *
-  * higher, and so cannot be installed.                                       *
+  * Do not worry if some "recommended" prerequisites are missing. You can install *
+  * them later if you need the features they provide. Do not proceed with the     *
+  * install if any of "REQUIRED" prerequisites are missing.                       *
+  *                                                                               *
+  * The optional Safe::World module does not currently run on Perl 5.10 or        *
+  * higher, and so cannot be installed.                                           *
 
 END
     }
