@@ -1,8 +1,8 @@
 package Bio::Graphics::Browser2;
-# $Id: Browser2.pm 23708 2010-08-27 15:04:55Z lstein $
+# $Id: Browser2.pm 23760 2010-09-13 22:15:07Z lstein $
 # Globals and utilities for GBrowse and friends
 
-our $VERSION = '2.14';
+our $VERSION = '2.15';
 
 use strict;
 use warnings;
@@ -282,7 +282,7 @@ sub session_args    {
 
 ## methods for dealing with data sources
 sub data_sources {
-  return sort shift->SUPER::configured_types();
+  return sort grep {!/^\s*=~/} shift->SUPER::configured_types();
 }
 
 sub data_source_description {
@@ -319,9 +319,10 @@ sub create_data_source {
   my $dsn  = shift;
   my $path = $self->data_source_path($dsn) or return;
   my ($regex_key) = grep { $dsn =~ /^$_$/ } map { $_ =~ s/^=~//; $_ } grep { $_ =~ /^=~/ } keys(%{$self->{config}});
+  my $name = $dsn;
   if ($regex_key) { $dsn = "=~".$regex_key; }
   my $source = Bio::Graphics::Browser2::DataSource->new($path,
-							$dsn,
+							$name,
 							$self->data_source_description($dsn),
 							$self) or return;
   if (my $adbs = $self->admin_dbs) {
