@@ -30,6 +30,7 @@ sub finish_load {
 
     # turn SAM file into a BAM file
     $self->set_status('converting SAM to BAM');
+    $self->do_strip_prefix($source_file);
     $self->sam2bam($source_file,$bam);
 
     # sort it
@@ -47,6 +48,24 @@ sub finish_load {
     $self->create_conf_file($bam);
 }
 
+sub do_strip_prefix {
+    my $self = shift;
+    my $source_file = shift;
+    my $prefix = $self->strip_prefix or return;
+    my $dest   = "$source_file.new";
+    open my $i,'<',$source_file  or die "Can't open $source_file: $!";
+    open my $o,">",$dest         or die "Can't open $dest: $!";
+    while (<$i>) {
+	next if /^\@/;
+	s/^([^\t]+)\t([^\t]+)\t$prefix([^\t]+)/$1\t$2\t$3/;
+    } continue {
+	print $o $_;
+    }
+    close $o;
+    close $i;
+    rename $dest,$source_file;
+}
+
 sub sam2bam {
     my $self = shift;
     my ($sampath,$bampath) = @_;
@@ -63,9 +82,10 @@ sub sam2bam {
 	my $fasta      = $self->get_fasta_file;
 	$fasta 
 	    or die "Could not find a suitable reference FASTA file for indexing this SAM file";
-    
+
 	my $fai = Bio::DB::Sam::Fai->load($fasta)
 	    or die "Could not load reference FASTA file for indexing this SAM file: $!";
+
 	$header = $tam->header_read2($fasta.".fai");
     }
 
