@@ -536,6 +536,13 @@ sub semantic_fallback_setting {
     return $self->fallback_setting($label,$option);
 }
 
+sub button_url {
+    my $self = shift;
+    my $globals = $self->globals;
+    my $path    = $self->global_setting('buttons');
+    return $globals->resolve_path($path,'url');
+}
+
 =head2 $section_setting = $data_source->section_setting($section_name)
 
 Returns "open" "closed" or "off" for the named section. Named sections are:
@@ -854,13 +861,19 @@ sub open_database {
 
   my ($dbid,$adaptor,@argv) = $self->db_settings($track,$length);
   my $db                    = Bio::Graphics::Browser2::DataBase->open_database($adaptor,@argv);
-
+  
   # do a little extra stuff the first time we see a new database
   unless ($self->{databases_seen}{$db}++) {
       my $refclass = $self->setting('reference class');
       eval {$db->default_class($refclass)} if $refclass;
       $db->strict_bounds_checking(1) if $db->can('strict_bounds_checking');
       $db->absolute(1)               if $db->can('absolute');
+
+      unless ($track eq 'general') {
+	  my $default = $self->open_database();  # I hope we don't get into a loop here
+	  eval {$db->dna_accessor($default)} unless $default eq $db;
+      }
+
   }
 
   # remember mapping of this database to this track
@@ -1015,7 +1028,7 @@ sub add_dbid_to_feature {
     if ($feature->isa('HASH')) {
 	$feature->{__gbrowse_dbid} = $dbid;
 	my $class = ref $feature;
-	return if $self->{hacked_classes}{$class}++;
+	return if $class->can('gbrowse_dbid');
 	my $method = sub {
 	    my $f = shift;
 	    return $f->{__gbrowse_dbid};
@@ -1026,7 +1039,7 @@ sub add_dbid_to_feature {
     else {
 	$self->{feature2dbid}{overload::StrVal($feature)} = $dbid;
 	my $class = ref $feature;
-	return if $self->{hacked_classes}{$class}++;
+	return if $class->can('gbrowse_dbid');
 	my $method = sub { my $f = shift;
 			   return $self->{feature2dbid}{overload::StrVal($f)}
 	  };
